# Luxsci.Api.SecureFormApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**DeleteSecureFormDatabaseFile**](SecureFormApi.md#deletesecureformdatabasefile) | **DELETE** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} |  |
| [**DeleteSecureFormDatabaseRow**](SecureFormApi.md#deletesecureformdatabaserow) | **DELETE** /account/{accountId}/secureforms/{formID}/db/rows/{index} |  |
| [**GetSecureForm**](SecureFormApi.md#getsecureform) | **GET** /account/{accountId}/secureforms/{formID} |  |
| [**GetSecureFormDatabaseFile**](SecureFormApi.md#getsecureformdatabasefile) | **GET** /account/{accountId}/secureforms/{formID}/db/{rowIndex}/file/{fileIndex} |  |
| [**GetSecureFormDatabasePosts**](SecureFormApi.md#getsecureformdatabaseposts) | **GET** /account/{accountId}/secureforms/{formID}/db |  |
| [**GetSecureFormDatabaseRow**](SecureFormApi.md#getsecureformdatabaserow) | **GET** /account/{accountId}/secureforms/{formID}/db/rows/{index} |  |
| [**GetSecureFormDatabaseRows**](SecureFormApi.md#getsecureformdatabaserows) | **GET** /account/{accountId}/secureforms/{formID}/db/rows |  |
| [**GetSecureFormList**](SecureFormApi.md#getsecureformlist) | **GET** /account/{accountId}/secureforms |  |

<a name="deletesecureformdatabasefile"></a>
# **DeleteSecureFormDatabaseFile**
> Authentication201Response DeleteSecureFormDatabaseFile (string accountId, string formID, string rowIndex, string fileIndex, string? cookie = null)



This function is used to remove a file associated with a row in your SecureForm database. {{ACL: Account: SecureForm Database - Delete}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteSecureFormDatabaseFileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var rowIndex = "rowIndex_example";  // string | 
            var fileIndex = "fileIndex_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteSecureFormDatabaseFile(accountId, formID, rowIndex, fileIndex);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.DeleteSecureFormDatabaseFile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteSecureFormDatabaseFileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteSecureFormDatabaseFileWithHttpInfo(accountId, formID, rowIndex, fileIndex);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.DeleteSecureFormDatabaseFileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **rowIndex** | **string** |  |  |
| **fileIndex** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | standard |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletesecureformdatabaserow"></a>
# **DeleteSecureFormDatabaseRow**
> Authentication201Response DeleteSecureFormDatabaseRow (string accountId, string formID, string index, string? cookie = null)



This function allows you to delete a row from your SecureForm database, based on the row index. This function will delete the row and any associated files.  This API call is audited: a record will be made of the particular API Integration and IP address that “deleted” each matching row (also implying that any associated files have been removed). {{ACL: Account: SecureForm Database - Delete}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteSecureFormDatabaseRowExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var index = "index_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteSecureFormDatabaseRow(accountId, formID, index);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.DeleteSecureFormDatabaseRow: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteSecureFormDatabaseRowWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteSecureFormDatabaseRowWithHttpInfo(accountId, formID, index);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.DeleteSecureFormDatabaseRowWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **index** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | standard simple response |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecureform"></a>
# **GetSecureForm**
> GetSecureForm200Response GetSecureForm (string accountId, string formID, string? cookie = null)



Returns details on a specific SecureForm configuration, based on the configuration’s unique ID.  {{ACL: Account: SecureForm Configuration}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureFormExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureForm200Response result = apiInstance.GetSecureForm(accountId, formID);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.GetSecureForm: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureFormWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureForm200Response> response = apiInstance.GetSecureFormWithHttpInfo(accountId, formID);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.GetSecureFormWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureForm200Response**](GetSecureForm200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The Response Body contains a “data” keyword contains one object which provides details about the specified form. The keywords and values in this object are the same as those defined for the “Get SecureForm List” operation. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecureformdatabasefile"></a>
# **GetSecureFormDatabaseFile**
> GetSecureFormDatabaseFile200Response GetSecureFormDatabaseFile (string accountId, string formID, string rowIndex, string fileIndex, string? cookie = null)



This function is used to retrieve a file associated with a row in your SecureForm database. You will need the row index and the file ID (which you can retrieve by reading the row data using other API calls).  If the file was encrypted at rest in the database, it will be decrypted for you.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each file. {{ACL: Account: SecureForm Database - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureFormDatabaseFileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var rowIndex = "rowIndex_example";  // string | 
            var fileIndex = "fileIndex_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureFormDatabaseFile200Response result = apiInstance.GetSecureFormDatabaseFile(accountId, formID, rowIndex, fileIndex);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabaseFile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureFormDatabaseFileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureFormDatabaseFile200Response> response = apiInstance.GetSecureFormDatabaseFileWithHttpInfo(accountId, formID, rowIndex, fileIndex);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabaseFileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **rowIndex** | **string** |  |  |
| **fileIndex** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureFormDatabaseFile200Response**](GetSecureFormDatabaseFile200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The JSON response body has a data object |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecureformdatabaseposts"></a>
# **GetSecureFormDatabasePosts**
> GetSecureFormDatabasePosts200Response GetSecureFormDatabasePosts (string accountId, string formID, string? afterDate = null, int? afterIndex = null, string? beforeDate = null, int? beforeIndex = null, string? fromDate = null, int? fromIndex = null, string? throughDate = null, int? throughIndex = null, string? cookie = null)



Returns details on the posts currently stored in the database table associated with a specific SecureForm configuration. This function is recommended for use when synchronizing or periodically downloading new rows to an external source: it allows you to quickly and easily see what, if any, entries are new relative to your last actions (if you saved the last index or date when you previously downloaded data).  You can optionally pass one or more parameters to narrow down the scope of what rows are examined to produce the summary results. By default, all table rows are examined. All criteria passed as parameters are used; it is possible (and easy) to specify mutually exclusive parameters that result in no rows being examined (e.g. all rows with an index greater than 100 and less than 50). {{ACL: Account: SecureForm Database - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureFormDatabasePostsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var afterDate = "afterDate_example";  // string? | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). (optional) 
            var afterIndex = 56;  // int? | All rows whose index is greater than the specified value (optional) 
            var beforeDate = "beforeDate_example";  // string? | DATETIME. All rows added before the specified date time (optional) 
            var beforeIndex = 56;  // int? | All rows whose index is less than the specified value (optional) 
            var fromDate = "fromDate_example";  // string? | DATETIME. All rows added on or after the specified date time (optional) 
            var fromIndex = 56;  // int? | All rows whose index is greater than or equal to the specified value. (optional) 
            var throughDate = "throughDate_example";  // string? | DATETIME. All rows added on or before the specified date time (optional) 
            var throughIndex = 56;  // int? | All rows whose index is less than or equal to the specified value. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureFormDatabasePosts200Response result = apiInstance.GetSecureFormDatabasePosts(accountId, formID, afterDate, afterIndex, beforeDate, beforeIndex, fromDate, fromIndex, throughDate, throughIndex);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabasePosts: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureFormDatabasePostsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureFormDatabasePosts200Response> response = apiInstance.GetSecureFormDatabasePostsWithHttpInfo(accountId, formID, afterDate, afterIndex, beforeDate, beforeIndex, fromDate, fromIndex, throughDate, throughIndex);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabasePostsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **afterDate** | **string?** | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). | [optional]  |
| **afterIndex** | **int?** | All rows whose index is greater than the specified value | [optional]  |
| **beforeDate** | **string?** | DATETIME. All rows added before the specified date time | [optional]  |
| **beforeIndex** | **int?** | All rows whose index is less than the specified value | [optional]  |
| **fromDate** | **string?** | DATETIME. All rows added on or after the specified date time | [optional]  |
| **fromIndex** | **int?** | All rows whose index is greater than or equal to the specified value. | [optional]  |
| **throughDate** | **string?** | DATETIME. All rows added on or before the specified date time | [optional]  |
| **throughIndex** | **int?** | All rows whose index is less than or equal to the specified value. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureFormDatabasePosts200Response**](GetSecureFormDatabasePosts200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The Response Body contains a “data” object with keywords and values. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecureformdatabaserow"></a>
# **GetSecureFormDatabaseRow**
> GetSecureFormDatabaseRow200Response GetSecureFormDatabaseRow (string accountId, string formID, string index, string? cookie = null)



This function works the same as “Get SecureForm Database Rows”, except that you specify the row index and get back up to 1 row. This index is the `\\_\\_index\\_\\_` field for the row.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each matching row.  {{ACL: Account: SecureForm Database - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureFormDatabaseRowExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var index = "index_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureFormDatabaseRow200Response result = apiInstance.GetSecureFormDatabaseRow(accountId, formID, index);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabaseRow: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureFormDatabaseRowWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureFormDatabaseRow200Response> response = apiInstance.GetSecureFormDatabaseRowWithHttpInfo(accountId, formID, index);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabaseRowWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **index** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureFormDatabaseRow200Response**](GetSecureFormDatabaseRow200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The JSON response body is the SAME as that returned for the “Database Rows” command, except that insted of a “rows” keyword with an array of matching rows, there is a &#x60;row&#x60; keyword which holds the object data for the requested row. This will be &#x60;null&#x60; if that row was not found. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecureformdatabaserows"></a>
# **GetSecureFormDatabaseRows**
> GetSecureFormDatabaseRows200Response GetSecureFormDatabaseRows (string accountId, string formID, string? afterDate = null, int? afterIndex = null, string? beforeDate = null, int? beforeIndex = null, string? fromDate = null, int? fromIndex = null, string? throughDate = null, int? throughIndex = null, string? cookie = null)



This function returns the actual content of all database rows matching your query. Encrypted database fields will be automatically decrypted and the actual values of the fields returned.  This API call is audited: a record will be made of the particular API Integration and IP address that “read” each matching row.  You can optionally pass one or more parameters to narrow down the scope of what rows are returned. These parameters are the same as those for “Get SecureForm Database Info”. {{ACL: Account: SecureForm Database - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureFormDatabaseRowsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var formID = "formID_example";  // string | 
            var afterDate = "afterDate_example";  // string? | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). (optional) 
            var afterIndex = 56;  // int? | All rows whose index is greater than the specified value (optional) 
            var beforeDate = "beforeDate_example";  // string? | DATETIME. All rows added before the specified date time (optional) 
            var beforeIndex = 56;  // int? | All rows whose index is less than the specified value (optional) 
            var fromDate = "fromDate_example";  // string? | DATETIME. All rows added on or after the specified date time (optional) 
            var fromIndex = 56;  // int? | All rows whose index is greater than or equal to the specified value. (optional) 
            var throughDate = "throughDate_example";  // string? | DATETIME. All rows added on or before the specified date time (optional) 
            var throughIndex = 56;  // int? | All rows whose index is less than or equal to the specified value. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureFormDatabaseRows200Response result = apiInstance.GetSecureFormDatabaseRows(accountId, formID, afterDate, afterIndex, beforeDate, beforeIndex, fromDate, fromIndex, throughDate, throughIndex);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabaseRows: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureFormDatabaseRowsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureFormDatabaseRows200Response> response = apiInstance.GetSecureFormDatabaseRowsWithHttpInfo(accountId, formID, afterDate, afterIndex, beforeDate, beforeIndex, fromDate, fromIndex, throughDate, throughIndex);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.GetSecureFormDatabaseRowsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **formID** | **string** |  |  |
| **afterDate** | **string?** | DATETIME. All rows added after thes pecified date time (in GMT, format “YYYY-MM-DD HH:MM:SS”). | [optional]  |
| **afterIndex** | **int?** | All rows whose index is greater than the specified value | [optional]  |
| **beforeDate** | **string?** | DATETIME. All rows added before the specified date time | [optional]  |
| **beforeIndex** | **int?** | All rows whose index is less than the specified value | [optional]  |
| **fromDate** | **string?** | DATETIME. All rows added on or after the specified date time | [optional]  |
| **fromIndex** | **int?** | All rows whose index is greater than or equal to the specified value. | [optional]  |
| **throughDate** | **string?** | DATETIME. All rows added on or before the specified date time | [optional]  |
| **throughIndex** | **int?** | All rows whose index is less than or equal to the specified value. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureFormDatabaseRows200Response**](GetSecureFormDatabaseRows200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Up to 500 rows can be returned per API call. If more rows match, only the first 500 (sorted by row index) are actually returned. The “data” body element will contain 2 items.  The first is called &#x60;fields&#x60;. This is an object where the keywords are the physical database column names in use for each column of data. These keywords correspond to the keywords in the objects returned in the &#x60;rows&#x60; array. The values of these keywords are corresponding the actual field names from your form. E.g., in many cases the form field name cannot be used “as is” as a database column name and must be “sanitized”. You can use this &#x60;fields&#x60; object to map between the database column names and the original form field names.  The second is called &#x60;rows&#x60;. This is an array of objects. Each object contains the data for a single matching row. The keywords are the database column names, the values are the row values for those columns. Values that were encrypted in the database are automatically decrypted and the real value is returned. If the row cannot be decrypted using the saved encryption key for this SecureForm configuration (e.g. if it was saved using some other SecureForm configuration and a different key), then the encrypted row values will all have the value of the word &#x60;ENCRYPTED&#x60;.  Files are not downloaded with this function; however, information as to what files are available is included with each row of data.  Separate functions are used to request individual files  Explanations of common database columns shown below. {{ACL: Account: SecureForm Database - Read}} |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getsecureformlist"></a>
# **GetSecureFormList**
> GetSecureFormList200Response GetSecureFormList (string accountId, string? cookie = null)



Return a list of all SecureForm configurations currently defined in your account. {{ACL: Account: SecureForm Configuration}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetSecureFormListExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new SecureFormApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetSecureFormList200Response result = apiInstance.GetSecureFormList(accountId);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling SecureFormApi.GetSecureFormList: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetSecureFormListWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetSecureFormList200Response> response = apiInstance.GetSecureFormListWithHttpInfo(accountId);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling SecureFormApi.GetSecureFormListWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetSecureFormList200Response**](GetSecureFormList200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The Response Body contains a “data” keyword which is an array of objects, one for each SecureForm configuration. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

