# Luxsci.Api.UsersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**ChangeUserPassword**](UsersApi.md#changeuserpassword) | **PUT** /user/{username}/password |  |
| [**CreateAppSpecificPassword**](UsersApi.md#createappspecificpassword) | **POST** /user/{username}/app-password/{suffix} |  |
| [**CreateUser**](UsersApi.md#createuser) | **POST** /account/{accountId}/users |  |
| [**DeleteAppSpecificPassword**](UsersApi.md#deleteappspecificpassword) | **DELETE** /user/{username}/app-password/{suffix} |  |
| [**DeleteUser**](UsersApi.md#deleteuser) | **DELETE** /account/{accountId}/users/{username} |  |
| [**GetTimeZonesList**](UsersApi.md#gettimezoneslist) | **GET** /user/{username}/settings/timezones |  |
| [**GetUser**](UsersApi.md#getuser) | **GET** /user/{username} |  |
| [**GetUserBrandingInformation**](UsersApi.md#getuserbrandinginformation) | **GET** /user/{username}/branding |  |
| [**GetUserProfile**](UsersApi.md#getuserprofile) | **GET** /user/{username}/profile |  |
| [**GetUserReport**](UsersApi.md#getuserreport) | **GET** /account/{accountId}/users |  |
| [**GetUserReport2**](UsersApi.md#getuserreport2) | **GET** /account/{accountId}/users/report |  |
| [**GetUserSettings**](UsersApi.md#getusersettings) | **GET** /user/{username}/settings |  |
| [**GetUserSingleSignOnLoginURL**](UsersApi.md#getusersinglesignonloginurl) | **GET** /user/{username}/password |  |
| [**GetUserSummaryReport**](UsersApi.md#getusersummaryreport) | **GET** /account/{accountId}/users/report_count |  |
| [**ListAllAppSpecificPassword**](UsersApi.md#listallappspecificpassword) | **GET** /user/{username}/app-password |  |
| [**ListAppSpecificPasswords**](UsersApi.md#listappspecificpasswords) | **GET** /user/{username}/app-password/{suffix} |  |
| [**RenameUser**](UsersApi.md#renameuser) | **POST** /account/{accountId}/users/{username}/rename |  |
| [**UpdateUser**](UsersApi.md#updateuser) | **PUT** /user/{username} |  |
| [**UpdateUserProfile**](UsersApi.md#updateuserprofile) | **PUT** /user/{username}/profile |  |
| [**UpdateUserSettings**](UsersApi.md#updateusersettings) | **PUT** /account/{accountId}/users/{username} |  |

<a name="changeuserpassword"></a>
# **ChangeUserPassword**
> Authentication201Response ChangeUserPassword (string username, ChangeUserPasswordRequest? changeUserPasswordRequest = null)



This command changes the user’s password. It validates the new password using all the same tests that would be applied if you were changing the password in the Web Interface. Make sure that the configuration settings for password strength validation are compatible with that used by your own applications generating the passwords.  You cannot change the passwords of users that have been disabled. You must re-enable them first, then change the password. {{ACL: User Settings - Change Password}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class ChangeUserPasswordExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var changeUserPasswordRequest = new ChangeUserPasswordRequest?(); // ChangeUserPasswordRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.ChangeUserPassword(username, changeUserPasswordRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.ChangeUserPassword: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the ChangeUserPasswordWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.ChangeUserPasswordWithHttpInfo(username, changeUserPasswordRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.ChangeUserPasswordWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **changeUserPasswordRequest** | [**ChangeUserPasswordRequest?**](ChangeUserPasswordRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **201** | Response description. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createappspecificpassword"></a>
# **CreateAppSpecificPassword**
> CreateAppSpecificPassword201Response CreateAppSpecificPassword (string username, string suffix, string? cookie = null, CreateAppSpecificPasswordRequest? createAppSpecificPasswordRequest = null)



This command creates a new user app-specific password/login for a specific user. Note that users can have at most 30 app-specific passwords defined at any one time. {{ACL: User Settings - Change Password}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateAppSpecificPasswordExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var suffix = "suffix_example";  // string | It is the plain text suffix to the user’s regular login email address that will be used to create this new app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@domain.com’, then the new login will be ‘usr@domain.com/email’.  The suffix string must be 1-10 characters long and can only contain letters and numbers. It is also case insensitive (so will be converted to lower case).'
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var createAppSpecificPasswordRequest = new CreateAppSpecificPasswordRequest?(); // CreateAppSpecificPasswordRequest? |  (optional) 

            try
            {
                CreateAppSpecificPassword201Response result = apiInstance.CreateAppSpecificPassword(username, suffix, cookie, createAppSpecificPasswordRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.CreateAppSpecificPassword: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateAppSpecificPasswordWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<CreateAppSpecificPassword201Response> response = apiInstance.CreateAppSpecificPasswordWithHttpInfo(username, suffix, cookie, createAppSpecificPasswordRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.CreateAppSpecificPasswordWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **suffix** | **string** | It is the plain text suffix to the user’s regular login email address that will be used to create this new app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@domain.com’, then the new login will be ‘usr@domain.com/email’.  The suffix string must be 1-10 characters long and can only contain letters and numbers. It is also case insensitive (so will be converted to lower case).&#39; |  |
| **cookie** | **string?** |  | [optional]  |
| **createAppSpecificPasswordRequest** | [**CreateAppSpecificPasswordRequest?**](CreateAppSpecificPasswordRequest?.md) |  | [optional]  |

### Return type

[**CreateAppSpecificPassword201Response**](CreateAppSpecificPassword201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **201** | The response body for a successful request will have a keywords and data in the “data” in the JSON response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="createuser"></a>
# **CreateUser**
> CreateUser200Response CreateUser (string accountId, string? cookie = null, CreateUserRequest? createUserRequest = null)



Create a new user in your account.  Your API Interface looks to see how many users were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional user creation requests until that situation changes. See your API Interface configuration page for your user creation limit.  If you would like to update other user information, such as contact information, disk quota, etc., you would use other, specific API calls. The user’s initial preferences are copied from the account main administrator user. This user will have all licenses and services that are currently being purchased “for all users” in your account or which are required (e.g. SecureLine for HIPAA or Archival in a domain provisioned for Archival).  **Upgrades:** If your account does not have available user licenses (or licenses for SecureLine, Archival, or other needed services) for this new user, then either the request will be rejected, or your account will be auto-upgraded if you have “Permit auto-upgrades as needed for fulfill requests” enabled. In the latter case, your account will be upgraded by a block of at least your specified “licenses at a time” upgrade setting from your API Interface configuration. {{ACL: Account: Users - Add}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateUserExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var createUserRequest = new CreateUserRequest?(); // CreateUserRequest? |  (optional) 

            try
            {
                CreateUser200Response result = apiInstance.CreateUser(accountId, cookie, createUserRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.CreateUser: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateUserWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<CreateUser200Response> response = apiInstance.CreateUserWithHttpInfo(accountId, cookie, createUserRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.CreateUserWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **createUserRequest** | [**CreateUserRequest?**](CreateUserRequest?.md) |  | [optional]  |

### Return type

[**CreateUser200Response**](CreateUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | \&quot;\&quot; |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteappspecificpassword"></a>
# **DeleteAppSpecificPassword**
> Authentication201Response DeleteAppSpecificPassword (string username, string suffix, string? cookie = null)



This command removes a user app-specific password/login for a specific user. {{ACL: User Settings - Change Password}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteAppSpecificPasswordExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var suffix = "suffix_example";  // string | It is the plain text suffix to the user’s regular login email address that will be used to identify the app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@ domain.com’, then the login deleted will be ‘usr@domain.com/email’.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteAppSpecificPassword(username, suffix);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.DeleteAppSpecificPassword: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteAppSpecificPasswordWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteAppSpecificPasswordWithHttpInfo(username, suffix);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.DeleteAppSpecificPasswordWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **suffix** | **string** | It is the plain text suffix to the user’s regular login email address that will be used to identify the app-specific password. E.g., if you specify “email” as the suffix for the user ‘user@ domain.com’, then the login deleted will be ‘usr@domain.com/email’. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **201** | Response description. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deleteuser"></a>
# **DeleteUser**
> UpdateUser200Response DeleteUser (string accountId, string username, string? cookie = null)



Delete the user from the system. This eliminates all the user’s data, history, web/ftp files, and email. After this command is complete, there will no longer be any record that the user existed. **This command cannot be undone.**  Note that some users cannot be deleted in this way. For example, any user with “account management” permission cannot be deleted. Other users may not be able to be deleted if there are things in your account (e.g., web sites) that are still owned by them. You will receive an error if you try to delete a user that is not currently deletable.  Note that deletion of a user does not downgrade your account. Please contact billing for account downgrade requests. {{ACL: Account: Users - Enable/Disable/Delete}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteUserExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                UpdateUser200Response result = apiInstance.DeleteUser(accountId, username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.DeleteUser: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteUserWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<UpdateUser200Response> response = apiInstance.DeleteUserWithHttpInfo(accountId, username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.DeleteUserWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**UpdateUser200Response**](UpdateUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | \&quot;\&quot; |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="gettimezoneslist"></a>
# **GetTimeZonesList**
> UpdateUser200Response GetTimeZonesList (string username, string? cookie = null)



Return a list of all available time zones. The keywords are the canonical time zone names. The values are plain text versions of the names.  Note, that with the “GMT+/-” times, specifically, the canonical name has the opposite sign compared to the common plain text version we all are used to seeing. E.g. “GMT-5” for Eastern Time USA, has a canonical name of “GMT+5”. Ya, weird, but based on how the standard time zone database works – we use these canonical names in conjunction with the standard time zone database to translate times from one time zone to another. So, if you are in “GMT+5”, your saved time zone name will be “GMT-5” so that, behind the scenes, the software can use this database to properly handle your time.  {{ACL: User Settings - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetTimeZonesListExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                UpdateUser200Response result = apiInstance.GetTimeZonesList(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetTimeZonesList: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetTimeZonesListWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<UpdateUser200Response> response = apiInstance.GetTimeZonesListWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetTimeZonesListWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**UpdateUser200Response**](UpdateUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The response body for a successful request will have a keywords and data in the “data” in the JSON response. The keywords are the time zone code names (e.g. “EST”) and the values are the descriptions for these names (e.g. “EST: Eastern Standard Time”). |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getuser"></a>
# **GetUser**
> GetUser200Response GetUser (string username, string? cookie = null)



Return contact information and other general metadata for the user. {{ACL: User Settings - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUser200Response result = apiInstance.GetUser(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUser: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUser200Response> response = apiInstance.GetUserWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUser200Response**](GetUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | User profile |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getuserbrandinginformation"></a>
# **GetUserBrandingInformation**
> GetUserBrandingInformation200Response GetUserBrandingInformation (string username, string? cookie = null)



Return information that can be used to brand (private label) a user interface consistently with the branding the user would experience when logging in to WebMail. Other keywords may be added in the future as the need arises. {{ACL: User Settings - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserBrandingInformationExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUserBrandingInformation200Response result = apiInstance.GetUserBrandingInformation(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserBrandingInformation: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserBrandingInformationWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserBrandingInformation200Response> response = apiInstance.GetUserBrandingInformationWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserBrandingInformationWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserBrandingInformation200Response**](GetUserBrandingInformation200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The response body for a successful request will have a keywords and data in the “data” in the JSON response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getuserprofile"></a>
# **GetUserProfile**
> GetUserProfile200Response GetUserProfile (string username, string? cookie = null)



Return contact information and other general metadata for the user.  This endpoint is the same as `getUser`. {{ACL: User Settings - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserProfileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUserProfile200Response result = apiInstance.GetUserProfile(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserProfile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserProfileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserProfile200Response> response = apiInstance.GetUserProfileWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserProfileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserProfile200Response**](GetUserProfile200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | User profile |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getuserreport"></a>
# **GetUserReport**
> GetUserReport200Response GetUserReport (string accountId, string? status = null, string? domain = null, int? youngerThan = null, int? olderThan = null, string? cookie = null)



Return an array of information about all users matching your query request.  The Request query string can contain any or all of the following keywords parameters to refine the search. If all are omitted, the report will include information about all users in the account. In all cases, any users protected from API access will not be included in the report. {{ACL: User Settings: Read Access }}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserReportExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var status = "enabled";  // string? | Value ‘enabled’ – return only active/enabled users.<br>Value ‘disabled’ – return only disabled users. (optional) 
            var domain = "domain_example";  // string? | Domain name in your account. If supplied, only users in this domain will be returned. (optional) 
            var youngerThan = 56;  // int? | Return only users created less than this number of days ago. (optional) 
            var olderThan = 56;  // int? | Return only users created more than this number of days ago. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUserReport200Response result = apiInstance.GetUserReport(accountId, status, domain, youngerThan, olderThan);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserReport: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserReportWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserReport200Response> response = apiInstance.GetUserReportWithHttpInfo(accountId, status, domain, youngerThan, olderThan);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserReportWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **status** | **string?** | Value ‘enabled’ – return only active/enabled users.&lt;br&gt;Value ‘disabled’ – return only disabled users. | [optional]  |
| **domain** | **string?** | Domain name in your account. If supplied, only users in this domain will be returned. | [optional]  |
| **youngerThan** | **int?** | Return only users created less than this number of days ago. | [optional]  |
| **olderThan** | **int?** | Return only users created more than this number of days ago. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserReport200Response**](GetUserReport200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The successful response will be an array of objects, one for each matching user in your account. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getuserreport2"></a>
# **GetUserReport2**
> GetUserSuppressionSummaryReport200Response GetUserReport2 (string accountId, string? afterDate = null, string? beforeDate = null, int? firstRow = null, string? fromDate = null, int? matches = null, string? throughDate = null, string? destination = null, string? destinationDirectory = null, string? destinationHostname = null, string? destinationPassword = null, string? destinationUsername = null, string? status = null, string? domain = null, string? cookie = null)



This report-style API call returns a list of all users in the account, with optional date range selection by user creation date. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#users). {{ACL: Account: View Reports}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserReport2Example
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var afterDate = "afterDate_example";  // string? | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT (optional) 
            var beforeDate = "beforeDate_example";  // string? | DATETIME. Return only matches dated before this date time. (optional) 
            var firstRow = 0;  // int? | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999. (optional)  (default to 0)
            var fromDate = "fromDate_example";  // string? | DATETIME. Return only matches dated on or after this date time. (optional) 
            var matches = 50000;  // int? | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. (optional)  (default to 50000)
            var throughDate = "throughDate_example";  // string? | DATETIME. Return only matches dated before or on this date time. (optional) 
            var destination = "destination_example";  // string? | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout - - uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. (optional) 
            var destinationDirectory = "destinationDirectory_example";  // string? | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command. (optional) 
            var destinationHostname = "destinationHostname_example";  // string? | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. (optional) 
            var destinationPassword = "destinationPassword_example";  // string? | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. (optional) 
            var destinationUsername = "destinationUsername_example";  // string? | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. (optional) 
            var status = "status_example";  // string? | Specify one of enabled or disabled to retrieve only enabled or disabled users. (optional) 
            var domain = "domain_example";  // string? | Enter the name of a domain to retrieve only users whose login is in that domain. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUserSuppressionSummaryReport200Response result = apiInstance.GetUserReport2(accountId, afterDate, beforeDate, firstRow, fromDate, matches, throughDate, destination, destinationDirectory, destinationHostname, destinationPassword, destinationUsername, status, domain);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserReport2: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserReport2WithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserSuppressionSummaryReport200Response> response = apiInstance.GetUserReport2WithHttpInfo(accountId, afterDate, beforeDate, firstRow, fromDate, matches, throughDate, destination, destinationDirectory, destinationHostname, destinationPassword, destinationUsername, status, domain);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserReport2WithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **afterDate** | **string?** | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional]  |
| **beforeDate** | **string?** | DATETIME. Return only matches dated before this date time. | [optional]  |
| **firstRow** | **int?** | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0] |
| **fromDate** | **string?** | DATETIME. Return only matches dated on or after this date time. | [optional]  |
| **matches** | **int?** | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000] |
| **throughDate** | **string?** | DATETIME. Return only matches dated before or on this date time. | [optional]  |
| **destination** | **string?** | For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout - - uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional]  |
| **destinationDirectory** | **string?** | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional]  |
| **destinationHostname** | **string?** | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional]  |
| **destinationPassword** | **string?** | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional]  |
| **destinationUsername** | **string?** | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional]  |
| **status** | **string?** | Specify one of enabled or disabled to retrieve only enabled or disabled users. | [optional]  |
| **domain** | **string?** | Enter the name of a domain to retrieve only users whose login is in that domain. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserSuppressionSummaryReport200Response**](GetUserSuppressionSummaryReport200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Report content |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getusersettings"></a>
# **GetUserSettings**
> GetUserSettings200Response GetUserSettings (string username, string? cookie = null)



Return information regarding selected user preferences and settings. Other keywords may be added in the future as the need arises. {{ACL: User Settings - Read}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserSettingsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUserSettings200Response result = apiInstance.GetUserSettings(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserSettings: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserSettingsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserSettings200Response> response = apiInstance.GetUserSettingsWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserSettingsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserSettings200Response**](GetUserSettings200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The response body for a successful request will have a keywords and data in the “data” in the JSON response. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getusersinglesignonloginurl"></a>
# **GetUserSingleSignOnLoginURL**
> GetUserSingleSignOnLoginURL200Response GetUserSingleSignOnLoginURL (string username, string ip, string? cookie = null)



Create a URL that the user can click on which will automatically log the user into the Web Interface without needing to enter his/her username and password. For example, if the user has already authenticated himself in your system, you can use this API call to get a link that can be presented to the user so the user can then access WebMail or other services without needing to login again (e.g. “single sign-on”).  Notes: 1. This API call returns a URL. You can have the user click on that URL or you can redirect him/her to it. 2. This URL is valid for 15 minutes from the time of issuance. It can be used multiple times while it is in use. 3. These URLs are invalidated if the user’s password is changed. 4. These URLs will only work for someone coming from the IP address that your specified in your request for the URL 5. If a user has a preference that permits only OpenID/Social media logins to his/her account, then this auto-login URL will not work. 6. If a user has two-factor authentication enabled, then this URL will take him through the username/password portion of the login process; however, the user will still have to do the chosen second factor. 7. All logins via Single Sign-on are logged and are denoted as Single Sign-on logins in the user’s login history report.

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserSingleSignOnLoginURLExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | Optional. Path after the domain name to take the user to upon automatic sign in. If omitted, the default path of “/perl/member/email/messages.pl” will be used; this default takes one to view the WebMail INBOX folder. You can use this parameter to select other destinations.
            var ip = 4.2.2.1;  // string | Required. This must be the IPv4 IP address that the end user is currently using. The resulting login URL will only work for someone who is coming from this specific IP address.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetUserSingleSignOnLoginURL200Response result = apiInstance.GetUserSingleSignOnLoginURL(username, ip);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserSingleSignOnLoginURL: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserSingleSignOnLoginURLWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserSingleSignOnLoginURL200Response> response = apiInstance.GetUserSingleSignOnLoginURLWithHttpInfo(username, ip);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserSingleSignOnLoginURLWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** | Optional. Path after the domain name to take the user to upon automatic sign in. If omitted, the default path of “/perl/member/email/messages.pl” will be used; this default takes one to view the WebMail INBOX folder. You can use this parameter to select other destinations. |  |
| **ip** | **string** | Required. This must be the IPv4 IP address that the end user is currently using. The resulting login URL will only work for someone who is coming from this specific IP address. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserSingleSignOnLoginURL200Response**](GetUserSingleSignOnLoginURL200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Response description. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getusersummaryreport"></a>
# **GetUserSummaryReport**
> GetUserSuppressionSummaryReport200Response GetUserSummaryReport (string accountId, string? afterDate = null, string? beforeDate = null, int? firstRow = null, string? fromDate = null, int? matches = null, string? throughDate = null, string? destination = null, string? destinationDirectory = null, string? destinationHostname = null, string? destinationPassword = null, string? destinationUsername = null, string? status = null, string? domain = null, string? cookie = null)



This report the number of users in the account, with optional date range selection by user creation date. See also [API Reporting Basics](/rest-api/reporting.html) and [report header columns in the response](/rest-api/report-responses.html#users_count).  {{ACL: Account: View Reports}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetUserSummaryReportExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var afterDate = "afterDate_example";  // string? | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT (optional) 
            var beforeDate = "beforeDate_example";  // string? | DATETIME. Return only matches dated before this date time. (optional) 
            var firstRow = 0;  // int? | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row=50000 to get rows 50000 to 99,999. (optional)  (default to 0)
            var fromDate = "fromDate_example";  // string? | DATETIME. Return only matches dated on or after this date time. (optional) 
            var matches = 50000;  // int? | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. (optional)  (default to 50000)
            var throughDate = "throughDate_example";  // string? | DATETIME. Return only matches dated before or on this date time. (optional) 
            var destination = "destination_example";  // string? | For reporting requests.  Specifying a destination makes the report \"asynchronous.\"  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \"job number\" and the filename that will be uploaded.  The supported value of \"destination\" is currently only \"sftp\" for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \"destination\" is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout - - uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. (optional) 
            var destinationDirectory = "destinationDirectory_example";  // string? | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \"chdir\" command. (optional) 
            var destinationHostname = "destinationHostname_example";  // string? | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. (optional) 
            var destinationPassword = "destinationPassword_example";  // string? | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. (optional) 
            var destinationUsername = "destinationUsername_example";  // string? | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. (optional) 
            var status = "status_example";  // string? | Specify one of enabled or disabled to retrieve only enabled or disabled users. (optional) 
            var domain = "domain_example";  // string? | Enter the name of a domain to retrieve only users whose login is in that domain. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857 ;  // string? |  (optional) 

            try
            {
                GetUserSuppressionSummaryReport200Response result = apiInstance.GetUserSummaryReport(accountId, afterDate, beforeDate, firstRow, fromDate, matches, throughDate, destination, destinationDirectory, destinationHostname, destinationPassword, destinationUsername, status, domain);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.GetUserSummaryReport: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetUserSummaryReportWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetUserSuppressionSummaryReport200Response> response = apiInstance.GetUserSummaryReportWithHttpInfo(accountId, afterDate, beforeDate, firstRow, fromDate, matches, throughDate, destination, destinationDirectory, destinationHostname, destinationPassword, destinationUsername, status, domain);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.GetUserSummaryReportWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **afterDate** | **string?** | DATETIME. Return only matches dated after this date time. Format “YYYY-MM-DD HH:MM:SS” in GMT | [optional]  |
| **beforeDate** | **string?** | DATETIME. Return only matches dated before this date time. | [optional]  |
| **firstRow** | **int?** | (Default value 0). All of the matches are sorted and numbered starting from 0. E.g. if you have 100,000 matches, these are rows 0 through 99,999. If you specify a first_row, then the returned matches will be those rows starting from that row. E.g. without a specification (or if you specify 0), you might get rows 0 through 49,999. In your next request you might specify first_row&#x3D;50000 to get rows 50000 to 99,999. | [optional] [default to 0] |
| **fromDate** | **string?** | DATETIME. Return only matches dated on or after this date time. | [optional]  |
| **matches** | **int?** | (Default value 50000). You can set matches to any value from 0 to 50000. This sets the maximum number of matches that will be returned in response to your request. Note that if the response size starts to exceed 50MB, then the response can still include fewer than your “matches” number, to keep the response size reasonable. If you specify “0” here, then no matches will be returned; however, you will still get the information on the number of matches that there were.  For asynchronous reports (ones where a destination is specified), the matches parameter is not limited to 50000, but it still defaults to 50000 if not specified. If you expect a larger number of rows, then you must explicitly approve the maximum size of the result set by setting matches appropriately.  This helps prevent accidental queries that produce very larger result sets. | [optional] [default to 50000] |
| **throughDate** | **string?** | DATETIME. Return only matches dated before or on this date time. | [optional]  |
| **destination** | **string?** | For reporting requests.  Specifying a destination makes the report \&quot;asynchronous.\&quot;  This means that a background job will be created to run the report and upload the final CSV file to the requested destination.  The API request to start the report will return immediately with a background \&quot;job number\&quot; and the filename that will be uploaded.  The supported value of \&quot;destination\&quot; is currently only \&quot;sftp\&quot; for a Secure FTP upload over SSH (as opposed to ftps, which would be a Secure FTP upload over SSL).  When \&quot;destination\&quot; is specified, additional destination parameters are also required.  Note that for SFTP uploads, there is a 15-minute upload timeout - - uploads that take longer (e.g., due to slow SFTP servers) will be aborted.  WARNING: Multiple concurrent large asynchronous report requests will impact your database performance: reports will take longer to generate and your LuxSci services will experience degraded/slower performance. | [optional]  |
| **destinationDirectory** | **string?** | For asynchronous reporting requests.  This optional parameter will be the subdirectory to change to on the SFTP server before uploading the report CSV file.  Technically speaking, this will be the argument provided to the SFTP \&quot;chdir\&quot; command. | [optional]  |
| **destinationHostname** | **string?** | For asynchronous reporting requests.  This will be the hostname of the SFTP server to which the report CSV file should be uploaded. | [optional]  |
| **destinationPassword** | **string?** | For asynchronous reporting requests.  This will be the password to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional]  |
| **destinationUsername** | **string?** | For asynchronous reporting requests.  This will be the username to be used for the login to the SFTP server to which the report CSV file should be uploaded. | [optional]  |
| **status** | **string?** | Specify one of enabled or disabled to retrieve only enabled or disabled users. | [optional]  |
| **domain** | **string?** | Enter the name of a domain to retrieve only users whose login is in that domain. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetUserSuppressionSummaryReport200Response**](GetUserSuppressionSummaryReport200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | Report content |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listallappspecificpassword"></a>
# **ListAllAppSpecificPassword**
> ListAppSpecificPasswords200Response ListAllAppSpecificPassword (string username, string? cookie = null)



This command creates a list of all app-specific password/logins defined for a specific user. This command does not allow you to access the passwords themselves, as these are stored only as complex hashes on the server.  A list of all defined app-specific passwords will be returned.  {{ACL: User Settings - Change Password}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class ListAllAppSpecificPasswordExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                ListAppSpecificPasswords200Response result = apiInstance.ListAllAppSpecificPassword(username);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.ListAllAppSpecificPassword: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the ListAllAppSpecificPasswordWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<ListAppSpecificPasswords200Response> response = apiInstance.ListAllAppSpecificPasswordWithHttpInfo(username);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.ListAllAppSpecificPasswordWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**ListAppSpecificPasswords200Response**](ListAppSpecificPasswords200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **201** | The response body for a successful request will have a list as the “data” in the JSON response. Each element of the list will be the definition of one of the app-specific passwords for this user. An app specific-password definitions is a list containing 4 elements:  [suffix, title, types, created, expires]  The “suffix” is the login suffix we have been using; “title” is the text description; “types” is the comma-delimited list of code words that defines the access available to this login; “created” is the date and time in GMT in the format “YYYY-MM-DD HHMMSS” of when this app-specific login was created. Expires is the similar date when it expires; if this is before “2020-01-01”, then it does not expire. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="listappspecificpasswords"></a>
# **ListAppSpecificPasswords**
> ListAppSpecificPasswords200Response ListAppSpecificPasswords (string username, string suffix, string? cookie = null)



This command creates a list of all app-specific password/logins defined for a specific user. This command does not allow you to access the passwords themselves, as these are stored only as complex hashes on the server.   The list will contain either 0 results (if there is no app-specific password defined with that suffix), or the 1 singular result corresponding to that suffix. {{ACL: User Settings - Change Password}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class ListAppSpecificPasswordsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var suffix = "suffix_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                ListAppSpecificPasswords200Response result = apiInstance.ListAppSpecificPasswords(username, suffix);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.ListAppSpecificPasswords: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the ListAppSpecificPasswordsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<ListAppSpecificPasswords200Response> response = apiInstance.ListAppSpecificPasswordsWithHttpInfo(username, suffix);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.ListAppSpecificPasswordsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **suffix** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**ListAppSpecificPasswords200Response**](ListAppSpecificPasswords200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The response body for a successful request will have a list as the “data” in the JSON response. Each element of the list will be the definition of one of the app-specific passwords for this user. An appspecific-password definitions is a list containing 4 elements:  [suffix, title, types, created, expires]  The “suffix” is the login suffix we have been using; “title” is the text description; “types” is the comma-delimited list of code words that defines the access available to this login; “created” is the date and time in GMT in the format “YYYY-MM-DD HHMMSS” of when this app-specific login was created. Expires is the similar date when it expires; if this is before “2020-01-01”, then it does not expire. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="renameuser"></a>
# **RenameUser**
> Authentication201Response RenameUser (string accountId, string username, string? cookie = null, RenameUserRequest? renameUserRequest = null)



Change the user’s login email address from `username` to `new_address`. E.g., change `john@sample.com` to `fred@newdomain.com`. Please note the following restrictions on this command:    1.  Users cannot be renamed with the API in the following situations:   1.  Users with account administration permission cannot be renamed.   2.  If this user is currently HIPAA compliant, s/he cannot be renamed into a domain that is not HIPAA compliant   3.  If this user does not have a SecureLine license, s/he cannot be renamed into a domain that is HIPAA- ompliant   4.  Users with Secure Marketing user logins associated with them cannot be renamed.   5.  Users cannot be renamed from a domain that does not have Premium Email Filtering or Archival into a domain that does. 2.  The new domain name (e.g. `newdomain.com`) must exist in this account. 3.  The user part of the new login (e.g. `fred`) must be valid for an email address and must not correspond to an existing user or email alias. 4.  Any existing PGP or S/MIME certificates associated with this user in the system will be deleted and become inaccessible, as they are explicitly related to the user’s login email address.  {{ACL: Account: Users - Enable / Disable / Delete Users}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class RenameUserExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var renameUserRequest = new RenameUserRequest?(); // RenameUserRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.RenameUser(accountId, username, cookie, renameUserRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.RenameUser: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the RenameUserWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.RenameUserWithHttpInfo(accountId, username, cookie, renameUserRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.RenameUserWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **renameUserRequest** | [**RenameUserRequest?**](RenameUserRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | none |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updateuser"></a>
# **UpdateUser**
> UpdateUser200Response UpdateUser (string username, string? cookie = null, UpdateUserRequest? updateUserRequest = null)



Update contact information for the user.  Same as `updateUserProfile`.  {{ACL: User Settings - Write}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class UpdateUserExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var updateUserRequest = new UpdateUserRequest?(); // UpdateUserRequest? |  (optional) 

            try
            {
                UpdateUser200Response result = apiInstance.UpdateUser(username, cookie, updateUserRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.UpdateUser: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the UpdateUserWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<UpdateUser200Response> response = apiInstance.UpdateUserWithHttpInfo(username, cookie, updateUserRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.UpdateUserWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **updateUserRequest** | [**UpdateUserRequest?**](UpdateUserRequest?.md) |  | [optional]  |

### Return type

[**UpdateUser200Response**](UpdateUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | User profile |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updateuserprofile"></a>
# **UpdateUserProfile**
> UpdateUser200Response UpdateUserProfile (string username, string? cookie = null, UpdateUserRequest? updateUserRequest = null)



Update contact information for the user. {{ACL: User Settings - Write}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class UpdateUserProfileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var updateUserRequest = new UpdateUserRequest?(); // UpdateUserRequest? |  (optional) 

            try
            {
                UpdateUser200Response result = apiInstance.UpdateUserProfile(username, cookie, updateUserRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.UpdateUserProfile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the UpdateUserProfileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<UpdateUser200Response> response = apiInstance.UpdateUserProfileWithHttpInfo(username, cookie, updateUserRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.UpdateUserProfileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **updateUserRequest** | [**UpdateUserRequest?**](UpdateUserRequest?.md) |  | [optional]  |

### Return type

[**UpdateUser200Response**](UpdateUser200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | User profile |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updateusersettings"></a>
# **UpdateUserSettings**
> Authentication201Response UpdateUserSettings (string accountId, string username, string? cookie = null, UpdateUserSettingsRequest? updateUserSettingsRequest = null)



Change one or more properties of the user. {{ACL: Account: Users - Modify}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class UpdateUserSettingsExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new UsersApi(config);
            var accountId = "accountId_example";  // string | 
            var username = "username_example";  // string | 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var updateUserSettingsRequest = new UpdateUserSettingsRequest?(); // UpdateUserSettingsRequest? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.UpdateUserSettings(accountId, username, cookie, updateUserSettingsRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling UsersApi.UpdateUserSettings: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the UpdateUserSettingsWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.UpdateUserSettingsWithHttpInfo(accountId, username, cookie, updateUserSettingsRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling UsersApi.UpdateUserSettingsWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **accountId** | **string** |  |  |
| **username** | **string** |  |  |
| **cookie** | **string?** |  | [optional]  |
| **updateUserSettingsRequest** | [**UpdateUserSettingsRequest?**](UpdateUserSettingsRequest?.md) |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | none |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

